## Django Archive

[![Build Status](https://travis-ci.org/nathan-osman/django-archive.svg?branch=master)](https://travis-ci.org/nathan-osman/django-archive)
[![Coverage Status](https://coveralls.io/repos/github/nathan-osman/django-archive/badge.svg?branch=master)](https://coveralls.io/github/nathan-osman/django-archive?branch=master)
[![Latest Documentation](https://readthedocs.org/projects/django-archive/badge/?version=latest)](http://django-archive.readthedocs.org/en/latest/)
[![PyPI Version](http://img.shields.io/pypi/v/django-archive.svg?style=flat)](https://pypi.python.org/pypi/django-archive)
[![PyPI Downloads](http://img.shields.io/pypi/dm/django-archive.svg?style=flat)](https://pypi.python.org/pypi/django-archive)
[![License](http://img.shields.io/badge/license-MIT-red.svg?style=flat)](http://opensource.org/licenses/MIT)

Django Archive provides a management command that will create a compressed archive of database tables and uploaded media.

### Documentation

For installation instructions and usage, please consult the documentation:

> http://django-archive.readthedocs.org/en/latest/
